@@ -30,7 +30,6 @@ from typing_extensions import (
     Any,
     Buffer,
     LiteralString,
-    NamedTuple,
     overload,
     ParamSpec,
     Protocol,
@@ -44,6 +43,7 @@ from typing_extensions import (
 from . import v2_v3_constants as v3c
 from . import v4_constants as v4c
 from .blocks_common import UnpackFrom
+from .options import GLOBAL_OPTIONS
 from .types import StrPath
 
 try:
@@ -171,7 +171,7 @@ def extract_xml_comment(comment: str) -> str:
                 for e in common_properties:
                     field = f"{e.get('name')}: {e.text}"
                     comments.append(field)
-                comment = "\n".join(field)
+                comment = "\n".join(comments)
             else:
                 comment = ""
         else:
@@ -223,10 +223,6 @@ class BlockKwargs(TypedDict, total=False):
     address: int
 
 
-def stream_is_mmap(_stream: FileLike | mmap.mmap, mapped: bool) -> TypeIs[mmap.mmap]:
-    return mapped
-
-
 @overload
 def get_text_v3(
     address: int,
@@ -274,7 +270,7 @@ def get_text_v3(address: int, stream: FileLike | mmap.mmap, mapped: bool = False
     if address == 0:
         return "" if decode else b""
 
-    if stream_is_mmap(stream, mapped):
+    if mapped:
         block_id = stream[address : address + 2]
         if block_id != b"TX":
             return "" if decode else b""
@@ -308,14 +304,6 @@ def get_text_v3(address: int, stream: FileLike | mmap.mmap, mapped: bool = False
     return text
 
 
-class MappedText(NamedTuple):
-    raw: bytes
-    decoded: str
-
-
-TxMap = dict[int, MappedText]
-
-
 @overload
 def get_text_v4(
     address: int,
@@ -323,7 +311,7 @@ def get_text_v4(
     mapped: bool = ...,
     decode: Literal[True] = ...,
     *,
-    tx_map: TxMap,
+    file_limit: int | float = float("inf"),
 ) -> str: ...
 
 
@@ -334,7 +322,7 @@ def get_text_v4(
     mapped: bool = ...,
     *,
     decode: Literal[False],
-    tx_map: TxMap,
+    file_limit: int | float = float("inf"),
 ) -> bytes: ...
 
 
@@ -345,7 +333,7 @@ def get_text_v4(
     mapped: bool = ...,
     decode: bool = ...,
     *,
-    tx_map: TxMap,
+    file_limit: int | float = float("inf"),
 ) -> bytes | str: ...
 
 
@@ -355,7 +343,7 @@ def get_text_v4(
     mapped: bool = False,
     decode: bool = True,
     *,
-    tx_map: TxMap,
+    file_limit: int | float = float("inf"),
 ) -> bytes | str:
     """Faster way to extract strings from MDF version 4 TextBlock.
 
@@ -370,8 +358,6 @@ def get_text_v4(
     decode : bool, default True
         Option to auto-detect character encoding and return decoded str instead
         of raw bytes.
-    tx_map : dict, optional
-        Map that contains interned strings.
 
     Returns
     -------
@@ -379,27 +365,43 @@ def get_text_v4(
         Unicode string or bytes object depending on the `decode` argument.
     """
 
-    if mapped_text := tx_map.get(address, None):
-        return mapped_text.decoded if decode else mapped_text.raw
+
 
     if address == 0:
-        tx_map[address] = MappedText(b"", "")
         return "" if decode else b""
 
-    if stream_is_mmap(stream, mapped):
+    if mapped:
+        if address + 16 > file_limit:
+            handle_incomplete_block(address)
+            return "" if decode else b""
+
         block_id, size = BLK_COMMON_uf(stream, address)
         if block_id not in (b"##TX", b"##MD"):
-            tx_map[address] = MappedText(b"", "")
             return "" if decode else b""
-        text_bytes = stream[address + 24 : address + size].split(b"\0", 1)[0].strip(b" \r\t\n")
+
+        if (end_of_string := address + size) > file_limit:
+            handle_incomplete_block(address)
+            return "" if decode else b""
+
+        text_bytes = stream[address + 24 : end_of_string].split(b"\0", 1)[0].strip(b" \r\t\n")
     else:
+        if address + 24 > file_limit:
+            handle_incomplete_block(address)
+            return "" if decode else b""
         stream.seek(address)
         block_id, size = BLK_COMMON_u(stream.read(24))
         if block_id not in (b"##TX", b"##MD"):
-            tx_map[address] = MappedText(b"", "")
             return "" if decode else b""
+
+        if address + size > file_limit:
+            handle_incomplete_block(address)
+            return "" if decode else b""
+
         text_bytes = stream.read(size - 24).split(b"\0", 1)[0].strip(b" \r\t\n")
 
+    if not decode:
+        return text_bytes
+
     try:
         decoded_text = text_bytes.decode("utf-8")
     except UnicodeDecodeError:
@@ -412,9 +414,7 @@ def get_text_v4(
         else:
             decoded_text = "<!text_decode_error>"
 
-    tx_map[address] = MappedText(text_bytes, decoded_text)
-
-    return decoded_text if decode else text_bytes
+    return decoded_text
 
 
 def sanitize_xml(text: str) -> str:
@@ -940,7 +940,7 @@ def count_channel_groups(
             raise MdfException(f"'{getattr(stream, 'name', stream)}' is not a valid MDF file")
 
     if version >= 4:
-        if stream_is_mmap(stream, mapped):
+        if mapped:
             dg_addr = UINT64_uf(stream, 88)[0]
             while dg_addr:
                 stream.seek(dg_addr + 32)
@@ -1938,3 +1938,16 @@ class Timer:
             )
         else:
             print(f"TIMER {self.name}:\n\t* inactive")
+
+
+def handle_incomplete_block(address: int, file: StrPath | None = None) -> None:
+    if file is None:
+        file = "The file"
+    else:
+        file = Path(file).name
+
+    msg = f"Incomplete block at 0x{address:x} exceeds the file size. {file} might be corrupted or partially written."
+    logger.warning(msg)
+
+    if GLOBAL_OPTIONS["raise_on_incomplete_blocks"]:
+        raise MdfException(msg)
