@@ -47,9 +47,8 @@ class AdvancedSearch(Ui_SearchDialog, QtWidgets.QDialog):
         self.setWindowIcon(icon)
 
         self.selection.can_delete_items = True
-        self.selection.all_texts = True
 
-        self.result = {}
+        self.payload = {}
         self.add_window_request = False
         if mdf:
             self.channels_db = mdf.channels_db
@@ -184,7 +183,7 @@ class AdvancedSearch(Ui_SearchDialog, QtWidgets.QDialog):
                             or pattern.fullmatch(cg_source.path or "")
                             or pattern.fullmatch(cg_source.name or "")
                             or pattern.fullmatch(cg_source.comment or "")
-                            or pattern.fullmatch(group.channel_group.name)
+                            or pattern.fullmatch(group.channel_group.acq_name or "")
                             or pattern.fullmatch(group.channel_group.comment)
                         ):
                             matches.update(
@@ -246,9 +245,10 @@ class AdvancedSearch(Ui_SearchDialog, QtWidgets.QDialog):
                     matches = {}
                     for name in found_names:
                         for entry in self.channels_db[name]:
+                            (group_index, channel_index) = entry
+                            ch = self.mdf.groups[group_index].channels[channel_index]
+
                             if entry not in matches:
-                                (group_index, channel_index) = entry
-                                ch = self.mdf.groups[group_index].channels[channel_index]
                                 cg = self.mdf.groups[group_index].channel_group
 
                                 source = ch.source or getattr(cg, "acq_source", None)
@@ -318,6 +318,7 @@ class AdvancedSearch(Ui_SearchDialog, QtWidgets.QDialog):
                 self.status.setText(str(err))
 
             self.matches.setSortingEnabled(True)
+            self.matches.collapseAll()
 
     def _add(self, event):
         selection = set()
@@ -344,26 +345,26 @@ class AdvancedSearch(Ui_SearchDialog, QtWidgets.QDialog):
 
     def _apply(self, event=None):
         if self._return_names:
-            self.result = set()
+            self.payload = set()
 
             iterator = QtWidgets.QTreeWidgetItemIterator(self.selection)
             while item := iterator.value():
-                self.result.add(item.text(self.NameColumn))
+                self.payload.add(item.text(self.NameColumn))
                 iterator += 1
         else:
-            self.result = {}
+            self.payload = {}
 
             iterator = QtWidgets.QTreeWidgetItemIterator(self.selection)
             while item := iterator.value():
                 entry = int(item.text(self.GroupColumn)), int(item.text(self.ChannelColumn))
                 name = item.text(self.NameColumn)
-                self.result[entry] = name
+                self.payload[entry] = name
                 iterator += 1
 
         self.accept()
 
     def _apply_pattern(self, event):
-        self.result = {
+        self.payload = {
             "pattern": self.pattern.text().strip(),
             "match_type": self.pattern_match_type.currentText(),
             "case_sensitive": self.case_sensitivity_pattern.currentText() == "Case sensitive",
@@ -376,11 +377,11 @@ class AdvancedSearch(Ui_SearchDialog, QtWidgets.QDialog):
             "y_range": sorted([self.y_range_min.value(), self.y_range_max.value()]),
         }
 
-        if not self.result["pattern"]:
+        if not self.payload["pattern"]:
             MessageBox.warning(self, "Cannot apply pattern", "The pattern cannot be empty")
             return
 
-        if not self.result["name"]:
+        if not self.payload["name"]:
             MessageBox.warning(self, "Cannot apply pattern", "The name cannot be empty")
             return
 
@@ -392,19 +393,19 @@ class AdvancedSearch(Ui_SearchDialog, QtWidgets.QDialog):
         self._apply()
 
     def _cancel(self, event):
-        self.result = {}
+        self.payload = {}
         self.reject()
 
     def _cancel_pattern(self, event):
-        self.result = {}
+        self.payload = {}
         self.reject()
 
     def _define_ranges(self, event=None):
         name = self.pattern.text().strip()
         dlg = RangeEditor(f"Channel of <{name}>", ranges=self.ranges, parent=self)
-        dlg.exec_()
+        dlg.exec()
         if dlg.pressed_button == "apply":
-            self.ranges = dlg.result
+            self.ranges = dlg.payload
 
     def _match_double_clicked(self, item):
         selection = set()
