@@ -66,6 +66,6 @@ class FlexRayBusTrace(TabularBase):
             self.remove_prefix.setCheckState(QtCore.Qt.CheckState.Checked)
 
         self._settings = QtCore.QSettings()
-        integer_mode = self._settings.value("tabular_format", "phys")
+        integer_mode = self._settings.value("tabular/integer_format", "phys")
 
         self.format_selection.setCurrentText(integer_mode)
