@@ -1,8 +1,6 @@
 #!/usr/bin/env python\
 
 import os
-import sys
-import unittest
 from unittest import mock
 
 from PySide6.QtCore import QPoint, QRect, QSettings, Qt
@@ -11,11 +9,15 @@ from PySide6.QtTest import QTest
 from PySide6.QtWidgets import QTreeWidgetItemIterator
 
 from asammdf import mdf
-from test.asammdf.gui.test_base import Pixmap
+from asammdf.gui.widgets.plot import PlotGraphics
+from test.asammdf.gui.test_base import Pixmap, safe_setup
 from test.asammdf.gui.widgets.test_BasePlotWidget import TestPlotWidget
 
 
 class TestPlotGraphicsShortcuts(TestPlotWidget):
+    pg: PlotGraphics
+
+    @safe_setup
     def setUp(self):
         """
         Events:
@@ -32,8 +34,8 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         """
         super().setUp()
         settings = QSettings()
-        settings.setValue("zoom_x_center_on_cursor", True)
-        settings.setValue("plot_cursor_precision", 6)
+        settings.setValue("plot/zoom/x_center_on_cursor", True)
+        settings.setValue("plot/cursor/display_precision", 6)
         # Open measurement file
         self.setUpFileWidget(measurement_file=self.measurement_file, default=True)
         # Switch ComboBox to "Natural sort"
@@ -114,25 +116,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         # Evaluate that two cursors are available
         self.assertEqual(2, len(cursors))
 
-        # Evaluate that new rectangle with different color is present
+        # area left of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
                 color_name=Pixmap.COLOR_BACKGROUND,
                 x=0,
                 y=0,
-                width=min(cursors) - 1,
-            )
-        )
-        self.assertTrue(
-            Pixmap.is_colored(
-                pixmap=range_pixmap,
-                color_name=Pixmap.COLOR_RANGE,
-                x=min(cursors) + 1,
-                y=0,
-                width=max(cursors),
+                width=min(cursors),
             )
         )
+
+        # area right of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
@@ -142,6 +137,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
             )
         )
 
+        # area inside range must have range color, first and last line are black
+        self.assertTrue(
+            Pixmap.is_colored(
+                pixmap=range_pixmap,
+                color_name=Pixmap.COLOR_RANGE,
+                x=min(cursors) + 1,
+                y=1,
+                width=max(cursors) - (min(cursors) + 1),
+                height=range_pixmap.height() - 2,
+            )
+        )
+
         # Move Cursors
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["move_cursor_left_1x"]))
         self.processEvents(timeout=0.01)
@@ -159,25 +166,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.assertEqual(cursors[0], new_cursors[0], "First cursor have new position after manipulation")
         self.assertNotEqual(cursors[1], new_cursors[1], "Second cursors have same position after manipulation")
 
-        # Evaluate that new rectangle with different color is present
+        # area left of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
                 color_name=Pixmap.COLOR_BACKGROUND,
                 x=0,
                 y=0,
-                width=min(new_cursors) - 1,
-            )
-        )
-        self.assertTrue(
-            Pixmap.is_colored(
-                pixmap=range_pixmap,
-                color_name=Pixmap.COLOR_RANGE,
-                x=min(new_cursors) + 1,
-                y=0,
-                width=max(new_cursors),
+                width=min(new_cursors),
             )
         )
+
+        # area right of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
@@ -187,6 +187,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
             )
         )
 
+        # area inside range must have range color, first and last line are black
+        self.assertTrue(
+            Pixmap.is_colored(
+                pixmap=range_pixmap,
+                color_name=Pixmap.COLOR_RANGE,
+                x=min(new_cursors) + 1,
+                y=1,
+                width=max(new_cursors) - (min(new_cursors) + 1),
+                height=range_pixmap.height() - 2,
+            )
+        )
+
         cursors = new_cursors
         # Press Key 'R' for range selection
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["toggle_range"]))
@@ -209,25 +221,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         for c in cursors:
             self.assertNotIn(c, new_cursors, f"cursor {c} is the same")
 
-        # Evaluate that new rectangle with different color is present
+        # area left of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
                 color_name=Pixmap.COLOR_BACKGROUND,
                 x=0,
                 y=0,
-                width=min(new_cursors) - 1,
-            )
-        )
-        self.assertTrue(
-            Pixmap.is_colored(
-                pixmap=range_pixmap,
-                color_name=Pixmap.COLOR_RANGE,
-                x=min(new_cursors) + 1,
-                y=0,
-                width=max(new_cursors),
+                width=min(new_cursors),
             )
         )
+
+        # area right of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
@@ -237,6 +242,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
             )
         )
 
+        # area inside range must have range color, first and last line are black
+        self.assertTrue(
+            Pixmap.is_colored(
+                pixmap=range_pixmap,
+                color_name=Pixmap.COLOR_RANGE,
+                x=min(new_cursors) + 1,
+                y=1,
+                width=max(new_cursors) - (min(new_cursors) + 1),
+                height=range_pixmap.height() - 2,
+            )
+        )
+
         # Press Key 'R' for range selection
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["range"]))
         self.processEvents(timeout=0.01)
@@ -263,9 +280,8 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         channel_color = self.channels[0].color.name()
 
         # Count intersections between middle line and signal
-        initial_intersections = Pixmap.color_map(self.pg.grab(QRect(0, int(self.pg.height() / 2), self.pg.width(), 1)))[
-            0
-        ].count(channel_color)
+        horizontal_line = QRect(0, int(self.pg.height() / 2), self.pg.width(), 1)
+        initial_intersections = Pixmap.color_map(self.pg.grab(horizontal_line))[0].count(channel_color)
         self.assertTrue(initial_intersections)
 
         # Setup for cursor
@@ -290,6 +306,7 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.assertEqual(len(cursors), 2)
 
         # Get a set of colors founded between cursors
+        self.is_not_blinking(self.pg, {channel_color})
         colors = Pixmap.color_names_exclude_defaults(
             self.pg.grab(QRect(cursors[0], 0, cursors[1] - cursors[0], self.pg.height()))
         )
@@ -302,9 +319,8 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.assertTrue(color)
 
         # Count intersection of midd line and signal between cursors
-        expected_intersections = Pixmap.color_map(
-            self.pg.grab(QRect(cursors[0], int(self.pg.height() / 2), cursors[1] - cursors[0], 1))
-        )[0].count(color)
+        horizontal_line = QRect(cursors[0], int(self.pg.height() / 2), cursors[1] - cursors[0], 1)
+        expected_intersections = Pixmap.color_map(self.pg.grab(horizontal_line))[0].count(color)
         self.assertTrue(expected_intersections)
 
         # Press key "X"
@@ -312,9 +328,8 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.processEvents()
 
         # Evaluate how much times signal intersect midd line
-        actual_intersections = Pixmap.color_map(self.pg.grab(QRect(0, int(self.pg.height() / 2), self.pg.width(), 1)))[
-            0
-        ].count(channel_color)
+        horizontal_line = QRect(0, int(self.pg.height() / 2), self.pg.width(), 1)
+        actual_intersections = Pixmap.color_map(self.pg.grab(horizontal_line))[0].count(channel_color)
         self.assertEqual(actual_intersections, expected_intersections)
         self.assertLess(actual_intersections, initial_intersections)
 
@@ -322,7 +337,6 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.assertAlmostEqual(self.pg.x_range[0], x_range[0], delta=0.001)
         self.assertAlmostEqual(self.pg.x_range[1], x_range[1], delta=0.001)
 
-    @unittest.skip("FIXME: test keeps failing in CI")
     def test_fit__stack_shortcuts(self):
         """
         Test Scope:
@@ -349,28 +363,32 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
             - Evaluate that all signals are continuous on plot
         """
 
-        def continuous(ch):
+        def continuous(signal_color: str) -> bool:
             pixmap = self.pg.grab()
-            image = pixmap.toImage()
-            signal_color = ch.color.name()
-            start, stop = Pixmap.search_signal_extremes_by_ax(pixmap, signal_color=signal_color, ax="x")
-            for x in range(start, stop + 1):
-                for j in range(self.pg.height()):
-                    if image.pixelColor(x, j).name() == signal_color:
-                        break
+            if extremes := Pixmap.search_signal_extremes_by_ax(pixmap, signal_color=signal_color, ax="X"):
+                start, stop = extremes
+            else:
+                return False
 
-                else:
-                    raise Exception(f"column {x} doesn't have color of channel {ch.name} from {start=} to {stop=}")
+            for x in range(start, stop + 1):
+                column_colors = Pixmap.color_names(self.pg.grab(QRect(x, 0, 1, pixmap.height())))
+                if signal_color not in column_colors:
+                    return False
+            return True
 
         self.pg.cursor1.color = "#000000"
         settings = QSettings()
-        settings.setValue("zoom_x_center_on_cursor", True)
+        settings.setValue("plot/zoom/x_center_on_cursor", True)
 
         self.add_channels([35, 36, 37])
 
         channel_35 = self.channels[0]
         channel_36 = self.channels[1]
         channel_37 = self.channels[2]
+        color_35 = channel_35.color.name()
+        color_36 = channel_36.color.name()
+        color_37 = channel_37.color.name()
+
         # Press "S"
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["stack_all"]))
         self.processEvents()
@@ -380,9 +398,9 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
             self.assertTrue(Pixmap.is_black(self.pg.grab(QRect(0, 0, self.pg.width(), 1))))
             # Top
             pixmap = self.pg.grab(QRect(0, 0, self.pg.width(), int(self.pg.height() / 3)))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertFalse(Pixmap.has_color(pixmap, color_36))
+            self.assertFalse(Pixmap.has_color(pixmap, color_37))
             # Midd
             pixmap = self.pg.grab(
                 QRect(
@@ -392,9 +410,9 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertFalse(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertFalse(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertFalse(Pixmap.has_color(pixmap, color_37))
             # Bottom
             pixmap = self.pg.grab(
                 QRect(
@@ -404,31 +422,29 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertFalse(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertFalse(Pixmap.has_color(pixmap, color_35))
+            self.assertFalse(Pixmap.has_color(pixmap, color_36))
+            self.assertTrue(Pixmap.has_color(pixmap, color_37))
             # Last 2 lines
 
             pixmap = self.pg.grab(QRect(0, self.pg.height() - 3, self.pg.width(), 2))
-            cn = Pixmap.color_names_exclude_defaults(pixmap)
-            self.assertEqual(len(cn), 0)
+            self.assertTrue(Pixmap.is_black(pixmap))
 
         # select the first channel
         self.mouseClick_WidgetItem(channel_35)
         # Press "Shift+F"
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["fit_selected"]))
-        self.avoid_blinking_issue(self.plot.channel_selection)
-        for _ in range(50):
-            self.processEvents()
+        self.is_not_blinking(self.pg, {color_35, color_36, color_37})
+
         # Evaluate
         with self.subTest("test_fit_selected_shortcut"):
             # First line
             self.assertTrue(Pixmap.is_black(self.pg.grab(QRect(0, 0, self.pg.width(), 1))))
             # Top
             pixmap = self.pg.grab(QRect(0, 0, self.pg.width(), int(self.pg.height() / 3)))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertFalse(Pixmap.has_color(pixmap, color_36))
+            self.assertFalse(Pixmap.has_color(pixmap, color_37))
             # Midd
             pixmap = self.pg.grab(
                 QRect(
@@ -438,9 +454,9 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertFalse(Pixmap.has_color(pixmap, color_37))
             # Bottom
             pixmap = self.pg.grab(
                 QRect(
@@ -450,9 +466,9 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertFalse(Pixmap.has_color(pixmap, color_36))
+            self.assertTrue(Pixmap.has_color(pixmap, color_37))
             # Last line
             self.assertTrue(Pixmap.is_black(self.pg.grab(QRect(0, self.pg.height() - 2, self.pg.width(), 1))))
 
@@ -460,16 +476,16 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.mouseClick_WidgetItem(channel_36)
         # Press "Shift+F"
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["stack_selected"]))
-        self.avoid_blinking_issue(self.plot.channel_selection)
+        self.is_not_blinking(self.pg, {color_35, color_36, color_37})
         # Evaluate
         with self.subTest("test_stack_selected_shortcut"):
             # First line
             self.assertTrue(Pixmap.is_black(self.pg.grab(QRect(0, 0, self.pg.width(), 1))))
             # Top
             pixmap = self.pg.grab(QRect(0, 0, self.pg.width(), int(self.pg.height() / 3)))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertFalse(Pixmap.has_color(pixmap, color_37))
             # Midd
             pixmap = self.pg.grab(
                 QRect(
@@ -479,9 +495,9 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertFalse(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertFalse(Pixmap.has_color(pixmap, color_37))
             # Bottom
             pixmap = self.pg.grab(
                 QRect(
@@ -491,24 +507,24 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertTrue(Pixmap.has_color(pixmap, color_37))
             # Last line
             self.assertTrue(Pixmap.is_black(self.pg.grab(QRect(0, self.pg.height() - 1, self.pg.width(), 1))))
 
             # Press "F"
             QTest.keySequence(self.pg, QKeySequence(self.shortcuts["fit_all"]))
-            self.avoid_blinking_issue(self.plot.channel_selection)
+            self.is_not_blinking(self.pg, {color_35, color_36, color_37})
             # Evaluate
         with self.subTest("test_fit_all_shortcut"):
             # First line
             self.assertTrue(Pixmap.is_black(self.pg.grab(QRect(0, 0, self.pg.width(), 1))))
             # Top
             pixmap = self.pg.grab(QRect(0, 0, self.pg.width(), int(self.pg.height() / 3)))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertTrue(Pixmap.has_color(pixmap, color_37))
             # Midd
             pixmap = self.pg.grab(
                 QRect(
@@ -518,9 +534,9 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertTrue(Pixmap.has_color(pixmap, color_37))
             # Bottom
             pixmap = self.pg.grab(
                 QRect(
@@ -530,9 +546,9 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                     int(self.pg.height() / 3),
                 )
             )
-            self.assertTrue(Pixmap.has_color(pixmap, channel_35.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_36.color.name()))
-            self.assertTrue(Pixmap.has_color(pixmap, channel_37.color.name()))
+            self.assertTrue(Pixmap.has_color(pixmap, color_35))
+            self.assertTrue(Pixmap.has_color(pixmap, color_36))
+            self.assertTrue(Pixmap.has_color(pixmap, color_37))
             # Last line
             self.assertTrue(Pixmap.is_black(self.pg.grab(QRect(0, self.pg.height() - 1, self.pg.width(), 1))))
 
@@ -542,15 +558,15 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
 
             # search if all channels are fitted into extremes
             self.mouseDClick_WidgetItem(channel_35)
-            continuous(channel_35)
+            self.assertTrue(continuous(color_35))
 
             self.mouseDClick_WidgetItem(channel_35)
             self.mouseDClick_WidgetItem(channel_36)
-            continuous(channel_36)
+            self.assertTrue(continuous(color_36))
 
             self.mouseDClick_WidgetItem(channel_36)
             self.mouseDClick_WidgetItem(channel_37)
-            continuous(channel_37)
+            self.assertTrue(continuous(color_37))
 
     def test_grid_shortcut(self):
         """
@@ -752,25 +768,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         # Evaluate that two cursors are available
         self.assertEqual(2, len(cursors))
 
-        # Evaluate that new rectangle with different color is present
+        # area left of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
                 color_name=Pixmap.COLOR_BACKGROUND,
                 x=0,
                 y=0,
-                width=min(cursors) - 1,
-            )
-        )
-        self.assertTrue(
-            Pixmap.is_colored(
-                pixmap=range_pixmap,
-                color_name=Pixmap.COLOR_RANGE,
-                x=min(cursors) + 1,
-                y=0,
-                width=max(cursors),
+                width=min(cursors),
             )
         )
+
+        # area right of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
@@ -780,6 +789,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
             )
         )
 
+        # area inside range must have range color, first and last line are black
+        self.assertTrue(
+            Pixmap.is_colored(
+                pixmap=range_pixmap,
+                color_name=Pixmap.COLOR_RANGE,
+                x=min(cursors) + 1,
+                y=1,
+                width=max(cursors) - (min(cursors) + 1),
+                height=range_pixmap.height() - 2,
+            )
+        )
+
         # Move Cursors
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["move_cursor_right_1x"]))
         self.processEvents(timeout=0.01)
@@ -797,25 +818,18 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         for c in cursors:
             self.assertNotIn(c, new_cursors, f"cursor {c} is the same")
 
-        # Evaluate that new rectangle with different color is present
+        # area left of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
                 color_name=Pixmap.COLOR_BACKGROUND,
                 x=0,
                 y=0,
-                width=min(new_cursors) - 1,
-            )
-        )
-        self.assertTrue(
-            Pixmap.is_colored(
-                pixmap=range_pixmap,
-                color_name=Pixmap.COLOR_RANGE,
-                x=min(new_cursors) + 1,
-                y=0,
-                width=max(new_cursors),
+                width=min(new_cursors),
             )
         )
+
+        # area right of range must have background color
         self.assertTrue(
             Pixmap.is_colored(
                 pixmap=range_pixmap,
@@ -824,6 +838,19 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                 y=0,
             )
         )
+
+        # area inside range must have range color, first and last line are black
+        self.assertTrue(
+            Pixmap.is_colored(
+                pixmap=range_pixmap,
+                color_name=Pixmap.COLOR_RANGE,
+                x=min(new_cursors) + 1,
+                y=1,
+                width=max(new_cursors) - (min(new_cursors) + 1),
+                height=range_pixmap.height() - 2,
+            )
+        )
+
         # Press Key 'R' for range selection
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["range"]))
         self.processEvents(timeout=0.01)
@@ -984,8 +1011,6 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.assertEqual(f"{ci.name} = {round(ch.signal.timestamps[pos], ci.precision)}{ci.unit}", ci.text())
         self.assertEqual(ch.signal.timestamps[pos], self.pg.cursor1.getXPos())
 
-    @unittest.skip("FIXME: test keeps failing in CI")
-    @unittest.skipIf(sys.platform != "win32", "RuntimeError. C++ object <<ViewBoxWithCursor>> already deleted.")
     def test_shift_channels_shortcut(self):
         """
         Test Scope:
@@ -1018,10 +1043,10 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.processEvents(0.1)
 
         # Find extremes of signals
-        old_from_to_y_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "y")
-        old_from_to_x_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "x")
-        old_from_to_y_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "y")
-        old_from_to_x_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "x")
+        old_from_to_y_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "Y")
+        old_from_to_x_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "X")
+        old_from_to_y_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "Y")
+        old_from_to_x_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "X")
 
         # Select first channel and move signal using commands Shift + PgDown/Down/Left
         self.mouseClick_WidgetItem(channel_36)
@@ -1029,8 +1054,7 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["shift_channels_down_1x"]))
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["shift_channels_left"]))
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["shift_channels_left"]))
-        self.avoid_blinking_issue(self.plot.channel_selection)
-        self.processEvents()
+        self.is_not_blinking(self.pg, {channel_36.color.name(), channel_37.color.name()})
 
         # Select second channel and move signal using commands Shift + PgUp/Up/Right
         self.mouseClick_WidgetItem(channel_37)
@@ -1038,14 +1062,13 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["shift_channels_up_1x"]))
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["shift_channels_right"]))
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["shift_channels_right"]))
-        self.avoid_blinking_issue(self.plot.channel_selection)
-        self.processEvents()
+        self.is_not_blinking(self.pg, {channel_36.color.name(), channel_37.color.name()})
 
         # Find new extremes
-        new_from_to_y_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "y")
-        new_from_to_y_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "y")
-        new_from_to_x_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "x")
-        new_from_to_x_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "x")
+        new_from_to_y_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "Y")
+        new_from_to_y_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "Y")
+        new_from_to_x_channel_36 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_36.color.name(), "X")
+        new_from_to_x_channel_37 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_37.color.name(), "X")
 
         # Evaluate
         self.assertLess(old_from_to_y_channel_36[0], new_from_to_y_channel_36[0])
@@ -1089,7 +1112,7 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         expected_normal_screen_honey_range = find_honey_range(self.pg)
         # Press "H"
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["honeywell"]))
-        self.avoid_blinking_issue(self.plot.channel_selection)
+        self.processEvents(0.01)
         delta_normal_screen_x_range = self.pg.x_range[1] - self.pg.x_range[0]
         # Evaluate
         self.assertAlmostEqual(delta_normal_screen_x_range, expected_normal_screen_honey_range, delta=0.0001)
@@ -1103,14 +1126,13 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         expected_full_screen_honey_range = find_honey_range(self.pg)
         # Press "H"
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["honeywell"]))
-        self.avoid_blinking_issue(self.plot.channel_selection)
+        self.processEvents(0.01)
         delta_full_screen_x_range = self.pg.x_range[1] - self.pg.x_range[0]
 
         # Evaluate
         self.assertNotEqual(delta_full_screen_x_range, delta_normal_screen_x_range)
         self.assertAlmostEqual(delta_full_screen_x_range, expected_full_screen_honey_range, delta=0.0001)
 
-    @unittest.skip("FIXME: test keeps failing in CI")
     def test_home_shortcuts(self):
         """
         Check if the signal is fitted properly after pressing key "W".
@@ -1126,7 +1148,7 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
             - Evaluate that after pressing key "W", signal is displayed from first to last column
         """
         settings = QSettings()
-        settings.setValue("zoom_x_center_on_cursor", True)
+        settings.setValue("plot/zoom/x_center_on_cursor", True)
 
         self.assertIsNotNone(self.add_channels([35]))
         channel_35 = self.channels[0]
@@ -1140,7 +1162,7 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         self.processEvents(0.01)
 
         # search first and last column where is displayed first signal
-        extremes_of_channel_35 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_35.color.name(), ax="x")
+        extremes_of_channel_35 = Pixmap.search_signal_extremes_by_ax(self.pg.grab(), channel_35.color.name(), ax="X")
         # Evaluate that there are extremes of first signal
         self.assertTrue(extremes_of_channel_35)
         # Press "I"
@@ -1159,7 +1181,7 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
         QTest.keySequence(self.pg, QKeySequence(self.shortcuts["home"]))
         self.processEvents()
         # Select all columns from left to right
-        for x in range(self.pg.height() - 1):
+        for x in range(self.pg.width()):
             column = self.pg.grab(QRect(x, 0, 1, self.pg.height()))
             if x < extremes_of_channel_35[0] - 1:
                 self.assertTrue(Pixmap.is_black(column), f"column {x} is not black")
@@ -1265,7 +1287,7 @@ class TestPlotGraphicsShortcuts(TestPlotWidget):
                 },
             }
             with mock.patch("asammdf.gui.widgets.plot.DefineChannel") as mo_DefineChannel:
-                mo_DefineChannel.return_value.result = computed_channel
+                mo_DefineChannel.return_value.payload = computed_channel
                 # Press key Insert
                 QTest.keySequence(self.plot.channel_selection, QKeySequence(self.shortcuts["insert_computation"]))
 
